# ###---------------------------------------------------------###
# file		: libraries.mk					#
# description	: Alliance Shared Libraries and Include Files	#
# ###---------------------------------------------------------###

# Last updated on on Tuesday 04 November 1997 at 19:17 MET

# ###---------------------------------------------------------###
#    general purpose utilities					#
# ###---------------------------------------------------------###

MUT_L      =  -lMut321
MUT_LIB    = libMut321.a
MUT_H      =    mut321.h

# ###---------------------------------------------------------###
#    functions related to cone net-list representation :	#
#								#
#      - cns : cone net_list					#
#      - yag : cone extractor form transistor net-list		#
# ###---------------------------------------------------------###

CNS_L      =  -lCns202
CNS_LIB    = libCns202.a
CNS_H      =    cns202.h

YAG_L      =  -lYag202
YAG_LIB    = libYag202.a
YAG_H      =    yag202.h

# ###---------------------------------------------------------###
#    functions related to net-list representation :		#
#								#
#      - mlo : basic data structures				#
#      - rcn : data structures for resistor representation	#
#								#
#      - mal : parser & driver for Al format			#
#      - mcl : parser & driver for COMPASS net-lists		#
#      - mel : parser & driver for EDIF				#
#      - mgl :          driver for VERILOG net-lists		#
#      - mhl :          driver for GHDL net-list		#
#      - msl : parser & driver for SPICE			#
#      - mvl : parser & driver for VHDL net-lists		#
#								#
#      - mlu : user level functions				#
# ###---------------------------------------------------------###

MLO_L      =  -lMlo407
MLO_LIB    = libMlo407.a
MLO_H      =    mlo407.h

RCN_L      =  -lRcn102
RCN_LIB    = libRcn102.a
RCN_H      =    rcn102.h

MAL_L      =  -lMal500
MAL_LIB    = libMal500.a

MCL_L      =  -lMcl410
MCL_LIB    = libMcl410.a

MEL_L      =  -lMel407
MEL_LIB    = libMel407.a

MHL_L      =  -lMhl403
MHL_LIB    = libMhl403.a

MGL_L      =  -lMgl100
MGL_LIB    = libMgl100.a

MSL_L      =  -lMsl614
MSL_LIB    = libMsl614.a

MVL_L      =  -lMvl409
MVL_LIB    = libMvl409.a

MLU_L      =  -lMlu414
MLU_LIB    = libMlu414.a
MLU_H      =    mlu414.h

# ###---------------------------------------------------------###
#    functions related to symbolic layout representation :	#
#								#
#      - mph : basic data structures				#
#								#
#      - map : parser & driver for AP format			#
#      - mcp : parser & driver for COMPASS Compose layout	#
#      - mmg : parser & driver for MODGEN			#
#								#
#      - mpu : user level functions				#
# ###---------------------------------------------------------###

MPH_L      =  -lMph406
MPH_LIB    = libMph406.a
MPH_H      =    mph406.h

MAP_L      =  -lMap405
MAP_LIB    = libMap405.a
MCP_L      =  -lMcp405
MCP_LIB    = libMcp405.a
MMG_L      =  -lMmg402
MMG_LIB    = libMmg402.a

MPU_L      =  -lMpu405
MPU_LIB    = libMpu405.a
MPU_H      =    mpu405.h

# ###---------------------------------------------------------###
#    user level functions for GENLIB				#
# ###---------------------------------------------------------###

MGN_L      =  -lMgn327
MGN_LIB    = libMgn327.a
MGN_H      =    mgn327.h

# ###---------------------------------------------------------###
#    functions related to expression representation :		#
#								#
#      - aut : utilites						#
#      - abl : lisp-like trees					#
#      - bdd : binary decision diagram				#
#      - gef : factorized expression representation		# 
# ###---------------------------------------------------------###

AUT_L      =  -lAut102
AUT_LIB    = libAut102.a
AUT_H      =    aut102.h

ABL_L      =  -lAbl102
ABL_LIB    = libAbl102.a
ABL_H      =    abl102.h

BDD_L      =  -lBdd102
BDD_LIB    = libBdd102.a
BDD_H      =    bdd102.h

# attention il s'agit de la lib luc
# ne pas utiliser avec aut abl bdd : utiliser log102...

LOG_L      =  -llog201
LOG_LIB    = liblog201.a
LOG_H      =    log201.h

# ###---------------------------------------------------------###
#    functions related to behavioural representation :		#
#								#
#      - beh : basic data structures				#
#      - bhl : high level functions				#
#      - bvl : parser & driver for Data-Flow VHDL and user	#
#              level functions					#
# ###---------------------------------------------------------###

BEH_L      =  -lBeh109
BEH_LIB    = libBeh109.a
BEH_H      =    beh109.h
BHL_L      =  -lBhl109
BHL_LIB    = libBhl109.a
BHL_H      =    bhl109.h
BVL_L      =  -lBvl111
BVL_LIB    = libBvl111.a
BVL_H      =    bvl111.h

# ###---------------------------------------------------------###
#    functions related to finite state machine representation :	#
#								#
#       - fsm : basic data structures				#
#       - fbh : intermediate data structures			#
#								#
#       - fvh : VHDL parser					#
#       - fks : KISS parser					#
# ###---------------------------------------------------------###

FSM_L      =  -lFsm102
FSM_LIB    = libFsm102.a
FSM_H      =    fsm102.h

FVH_L      =  -lFvh102
FVH_LIB    = libFvh102.a
FKS_L      =  -lFks102
FKS_LIB    = libFks102.a

FTL_L      =  -lFtl102
FTL_LIB    = libFtl102.a
FTL_H      =    ftl102.h

# ###---------------------------------------------------------###
#    functions related to simulation patterns representation :	#
#								#
#      - pat : basic data structures				#
#      - phl : high level functions				#
#      - ppt : parser & driver for PAT format and user level	#
#              functions					#
#      - pgn : user level functions for GENPAT			#
# ###---------------------------------------------------------###

PAT_L      =  -lPat106
PAT_LIB    = libPat106.a
PAT_H      =    pat106.h
PHL_L      =  -lPhl106
PHL_LIB    = libPhl106.a
PHL_H      =    phl106.h
PPT_L      =  -lPpt106
PPT_LIB    = libPpt106.a
PPT_H      =    ppt106.h
PGN_L      =  -lPgn102
PGN_LIB    = libPgn102.a
PGN_H      =    Pgn102.h

# ###---------------------------------------------------------###
#    functions related to physical (micron) layout :		#
#								#
#      - rds : basic data structures				#
#      - rut : user level functions				#
#								#
#      - rdf : parser & driver for CIF format			#
#      - rgs : parser & driver for GDSII format			#
#      - rfm : physical layout from symbolic layout		#
#      - rpr : parser for technology file			#
#      - rwi : windowing functions				#
#								#
#      - rtl : user level functions				#
# ###---------------------------------------------------------###

RDS_L      =  -lRds207
RDS_LIB    = libRds207.a
RDS_H      =    rds207.h

RUT_L      =  -lRut206
RUT_LIB    = libRut206.a
RUT_H      =    rut206.h

RCF_L      =  -lRcf109
RCF_LIB    = libRcf109.a
RFM_L      =  -lRfm208
RFM_LIB    = libRfm208.a
RFM_H      =    rfm208.h
RGS_L      =  -lRgs110
RGS_LIB    = libRgs110.a
RPR_L      =  -lRpr210
RPR_LIB    = libRpr210.a
RPR_H      =    rpr210.h
RWI_L      =  -lRwi107
RWI_LIB    = libRwi107.a
RWI_H      =    rwi107.h

RTL_L      =  -lRtl108
RTL_LIB    = libRtl108.a
RTL_H      =    rtl108.h

# ###---------------------------------------------------------###
#    functions related to icon representation :			#
#								#
#      - icn : basic data structures				#
#								#
#      - ica : parser & driver for Alliance icon format		#
#      - icc : parser & driver for Compass  icon format		#
#								#
#      - icu : user level functions				#
# ###---------------------------------------------------------###

ICN_L      =  -lIcn201
ICN_LIB    = libIcn201.a
ICN_H      =    icn201.h

IAC_H      =    iac201.h

ICA_L      =  -lIca201
ICA_LIB    = libIca201.a
ICC_L      =  -lIcc201
ICC_LIB    = libIcc201.a

ICU_L      =  -lIcu201
ICU_LIB    = libIcu201.a
ICU_H      =    icu201.h

# ###---------------------------------------------------------###
#    functions related to portable blocks generators :		#
#								#
#      - gbs : barrel shifter					#
#      - gga : fast adder					#
#      - ggr : rom						#
#      - grf : register file					#
#      - gam : array pipelined multiplier			#
#      - gfp : data path simple operators			#
# ###---------------------------------------------------------###

GBS_L      =  -lGbs201
GBS_LIB    = libGbs201.a
GBS_H      =    gbs201.h

GGA_L      =  -lGga301
GGA_LIB    = libGga301.a
GGA_H      =    gga301.h

GGR_L      =  -lGgr001
GGR_LIB    = libGgr001.a
GGR_H      =    ggr001.h

GRF_L      =  -lGrf604
GRF_LIB    = libGrf604.a
GRF_H      =    grf604.h

GAM_L      =  -lGam000
GAM_LIB    = libGam000.a
GAM_H      =    gam000.h

GFP_L      =  -lGfp110
GFP_LIB    = libGfp110.a
GFP_H      =    gfp110.h

# ###---------------------------------------------------------###
#    place & route functions					#
# ###---------------------------------------------------------###

APR_L      =  -lApr102
APR_LIB    = libApr102.a
APR_H      =    apr102.h

# ###---------------------------------------------------------###
#    design rule checker functions				#
# ###---------------------------------------------------------###

VRD_L      =  -lVrd300
VRD_LIB    = libVrd300.a
VRD_H      =    vrd300.h

# ###---------------------------------------------------------###
#    user level functions for FPGEN				#
# ###---------------------------------------------------------###

FGN_L      =  -lFgn110
FGN_LIB    = libFgn110.a
FGN_H        = Fgn107.h

# ###---------------------------------------------------------###
#    schematic assistant					#
#								#
#      - saB : basic data structures				#
#      - sax : high level functions				#
# ###---------------------------------------------------------###

SAB_L   =  -lSaB402
SAB_LIB = libSaB402.a
SAB_H   =    sab402.h

SAX_L   =  -lSax102
SAX_LIB = libSax102.a
SAX_H   =    sax102.h

# ###---------------------------------------------------------###
#    Timing Analysis						#
#								#
#      - ttv : basic timing data structures			#
#								#
#      - inf : information file parser				#
#      - elp : electrical parameters' file parser		#
#      - tas : static delay analysis functions			#
# ###---------------------------------------------------------###

TTV_L      =  -lTtv110
TTV_LIB    = libTtv110.a
TTV_H      =    ttv110.h

INF_L      =  -lInf109
INF_LIB    = libInf109.a
INF_H      =    inf109.h

ELP_L      =  -lElp104
ELP_LIB    = libElp104.a
ELP_H      =    elp104.h

TAS_L      =  -lTas521
TAS_LIB    = libTas521.a
TAS_H      =    tas521.h

FCL_L      =  -lFcl102
FCL_LIB    = libFcl102.a
FCL_H      =    fcl102.h
